Use Case:  Give local roles to other users
==========================================

Actor
-----

Content Creator

Overview
--------

In order to collaborate on a set of content, each contributor
must have the appropriate permissions to create and revise
content.

Assumptions
-----------

Content Creator has logged into the CMF (see :doc:`LoginAsMember`).

Procedure
---------

1. Navigate to a folder where you wish to give local roles to other users so
   you can collaborate on content.

2. Select 'Folder contents' from the actions box.

3. Select 'Set local roles' from the actions box.

4. Fill out the search form as follows:

   **Search Term** --
     Enter the name or email address of the user to whom you wish to assign
     local roles.

   **Search By** --
     Selected the appropriate drop down which corresponds to the kind of
     search term you have entered (e.g. 'Email Address' or 'User ID')

5. Click the Search button. The system will redisplay the form, showing a
   list of users matching your criterion.

6. Select users by checking the corresponding checkbox. Select the role to
   assign to the selected user(s) from the drop down menu labled **Role to
   Assign**. Click the "Assign Roles" button. The system will assign the
   selected role to the selected users, and redisplay the local roles form with
   a message indicating the change.
